@@ -1,5 +1,8 @@
-require 'test_helper'
-class DecompressorTest < MiniTest::Test
+# frozen_string_literal: true
+
+require_relative 'test_helper'
+
+class DecompressorTest < Minitest::Test
   TEST_COMPRESSION_METHOD = 255
 
   class TestCompressionClass
