@@ -1,7 +1,10 @@
-require 'test_helper'
+# frozen_string_literal: true
+
+require_relative '../test_helper'
+
 require 'zip/filesystem'
 
-class ZipFsFileStatTest < MiniTest::Test
+class FileStatTest < Minitest::Test
   def setup
     @zip_file = ::Zip::File.new('test/data/zipWithDirs.zip')
   end
@@ -11,7 +14,7 @@ class ZipFsFileStatTest < MiniTest::Test
   end
 
   def test_blocks
-    assert_equal(nil, @zip_file.file.stat('file1').blocks)
+    assert_nil(@zip_file.file.stat('file1').blocks)
   end
 
   def test_ino
@@ -19,11 +22,11 @@ class ZipFsFileStatTest < MiniTest::Test
   end
 
   def test_uid
-    assert_equal(0, @zip_file.file.stat('file1').uid)
+    assert_equal(500, @zip_file.file.stat('file1').uid)
   end
 
   def test_gid
-    assert_equal(0, @zip_file.file.stat('file1').gid)
+    assert_equal(500, @zip_file.file.stat('file1').gid)
   end
 
   def test_ftype
@@ -32,10 +35,10 @@ class ZipFsFileStatTest < MiniTest::Test
   end
 
   def test_mode
-    assert_equal(0600, @zip_file.file.stat('file1').mode & 0777)
-    assert_equal(0600, @zip_file.file.stat('file1').mode & 0777)
-    assert_equal(0755, @zip_file.file.stat('dir1').mode & 0777)
-    assert_equal(0755, @zip_file.file.stat('dir1').mode & 0777)
+    assert_equal(0o600, @zip_file.file.stat('file1').mode & 0o777)
+    assert_equal(0o600, @zip_file.file.stat('file1').mode & 0o777)
+    assert_equal(0o755, @zip_file.file.stat('dir1').mode & 0o777)
+    assert_equal(0o755, @zip_file.file.stat('dir1').mode & 0o777)
   end
 
   def test_dev
