@@ -1,6 +1,8 @@
-require 'test_helper'
+# frozen_string_literal: true
 
-class Zip64SupportTest < MiniTest::Test
+require_relative 'test_helper'
+
+class Zip64SupportTest < Minitest::Test
   TEST_FILE = File.join(File.dirname(__FILE__), 'data', 'zip64-sample.zip')
 
   def test_open_zip64_file
@@ -11,5 +13,4 @@ class Zip64SupportTest < MiniTest::Test
     assert(test_rb.size == 482)
     assert(test_rb.compressed_size == 229)
   end
-
 end
